==> haskell-hastache-0.6.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-4h5AV3BKP66F6VRMyc3oZZ
key: hastache-0.6.1-4h5AV3BKP66F6VRMyc3oZZ
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: 574f3daa1a342c24204446c20a34c90e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/hastache-0.6.1
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/hastache-0.6.1
hs-libraries: HShastache-0.6.1-4h5AV3BKP66F6VRMyc3oZZ
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.3.0.0
    filepath-1.4.1.1 ieee754-0.8.0-CDXZC1OkvI520r7z7XGrZG
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 syb-0.6-IcoSwlPi2Nx4zSqMmorFPS
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hastache-0.6.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-5m66mkxXxs5IPYry4H9s05
key: hastache-0.6.1-5m66mkxXxs5IPYry4H9s05
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: 6465986d9876adf68251dd7a3cc578d3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/hastache-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/hastache-0.6.1
hs-libraries: HShastache-0.6.1-5m66mkxXxs5IPYry4H9s05
depends:
    base-4.9.1.0 blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.3.0.0
    filepath-1.4.1.1 ieee754-0.8.0-CDXZC1OkvI520r7z7XGrZG
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6 syb-0.7-4OKdCpwGutyB1rNRmoa0ya
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
